/**
 * @file aisl/client.h
 *
 * Copyright (c) 2017-2019 by Löwenware Ltd.
 *
 * Project homepage: https://lowenware.com/aisl/
 *
 */

#ifndef AISL_CLIENT_H_A6C37DCF_2183_4F22_A5A0_668311757A08
#define AISL_CLIENT_H_A6C37DCF_2183_4F22_A5A0_668311757A08

#include <aisl/types.h>


/**
 * @brief Gets #aisl_server_t instance associated with client.
 * @param client an #aisl_client_t instance pointer.
 * @return an associated #aisl_server_t pointer.
 */
aisl_server_t
aisl_client_get_server(aisl_client_t client);


/**
 * @brief Gets security connection status.
 * @param client an #aisl_client_t instance pointer.
 * @return true if SSL is enabled and false if disabled.
 */
bool
aisl_client_is_secure(aisl_client_t client);


/**
 * @brief Gets client's connection state.
 * @param client an #aisl_client_t instance pointer.
 * @return true if client is online and false if is offline.
 */
bool
aisl_client_is_online(aisl_client_t client);


/**
 * @brief Forcefully closes client's connection.
 * @param client an #aisl_client_t instance pointer.
 */
void
aisl_client_disconnect(aisl_client_t client);


/**
 * @brief Gets HTTP protocol version.
 * @param client an #aisl_client_t instance pointer.
 * @return HTTP protocol version
 */
aisl_http_version_t
aisl_client_get_http_version(aisl_client_t client);


void
aisl_client_get_address( aisl_client_t client, struct sockaddr_in * address);

#endif /* !AISL_CLIENT_H */
