/*
 * src/instance.h
 *
 * Copyright (C) 2019 Ilja Kartašov <ik@lowenware.com>
 *
 * Project homepage: https://lowenware.com/aisl/
 *
 */

#ifndef AISL_INSTANCE_H_814CF474_A646_45B7_B6B2_3F4C7BEFA484
#define AISL_INSTANCE_H_814CF474_A646_45B7_B6B2_3F4C7BEFA484

#ifndef AISL_WITHOUT_SSL
#include <openssl/ssl.h>
#endif

#include <aisl/instance.h>
#include "ssl.h"
#include "list.h"


struct aisl
{
  aisl_server_t * srv;
  #ifndef AISL_WITHOUT_SSL
  aisl_ssl_t    * ssl;
  #endif
  struct list     client_spool;
  aisl_callback_t callback;
  void          * p_ctx;

  uint32_t        accept_limit;
  uint32_t        silence_timeout;
  uint32_t        buffer_size;
};


#ifndef AISL_WITHOUT_SSL
/**
 * @brief Gets SSL context for appropriate server name.
 * @param instance a pointer to #aisl_t instance.
 * @param server_name a null-terminated string with server name or NULL.
 * @return a pointer to SSL context
 */
SSL_CTX *
aisl_get_ssl_ctx( aisl_t instance, const char * server_name );
#endif


/** 
 * @brief Raises event from source.
 * @param instance a pointer to #aisl_t instance.
 * @param evt a pointer to event structure.
 */
void
aisl_raise_evt( aisl_t instance, aisl_evt_t const evt );


void
aisl_raise( aisl_t          instance,
            void          * source,
            aisl_evt_code_t code,
            aisl_status_t   status );

#endif /* !AISL_INSTANCE_H */
