/*
 * @file src/server.h
 *
 * Copyright (c) 2017-2019 by Löwenware Ltd.
 *
 * Project homepage: https://lowenware.com/aisl/
 *
 */

#ifndef AISL_SERVER_H_FACD3B4D_0D72_4345_9A30_811103DA9AE2
#define AISL_SERVER_H_FACD3B4D_0D72_4345_9A30_811103DA9AE2

#include <aisl/config.h>
#include <aisl/server.h>

#define AISL_SERVER(x) ((aisl_server_t) x)

/**
 * @brief HTTP(s) server data structure represented by #aisl_server_t pointer.
 */
struct aisl_server
{
  struct sockaddr_in   address;  /**< TCP server address to listen to. */
  aisl_t               instance; /**< Associated AISL instance pointer. */
  int                  fd;       /**< System socket descriptor. */
  bool                 ssl;      /**< SSL enabled/disabled flag. */
};

/**
 * @brief Allocates and instance of #aisl_server_t.
 * @param cfg_srv a pointer to server configuration structure.
 * @param instance a pointer to #aisl_t instance.
 * @return a pointer to #aisl_server_t instance.
 */
aisl_server_t
aisl_server_new(aisl_cfg_srv_t const cfg_srv, aisl_t instance);


/**
 * @brief Frees memory allocated for #aisl_server_t instance.
 * @param server a pointer to #aisl_server_t instance.
 */
void
aisl_server_free(aisl_server_t server);


/**
 * @brief Does server routines.
 * Tries to open server if it was not opened yet, otherwise tries to accept a
 * new client connecting to the server.
 * @param server a pointer to #aisl_server_t instance.
 * @param p_client a pointer to store #aisl_client_t instance pointer.
 * @return #aisl_status_t code:
 * - AISL_SUCCESS if client connected,
 * - AISL_IDLE if there is no client to connect,
 * - AISL_SYSCALL_ERROR if error occured.
 */
aisl_status_t
aisl_server_touch( aisl_server_t   server,
                   aisl_client_t * p_client );


/**
 * @brief Gets a socket descriptor associated with HTTP client.
 * @param server a pointer to #aisl_server_t instance.
 * @return a client socket descriptor.
 */
int
aisl_server_get_socket(aisl_server_t server);


#endif /* !AISL_SERVER_H */
